﻿///////////////////////////////////////////////////////////////////////////////////////////////////
// 
//  ACT距離計算サービス サンプルプログラム
//  CalcSettingsクラス
//
//  Copyrights (c) 2016-2023, Advanced Core Technologies, Inc. All rights reserved.
//
//  2023/09/21 Rev.1.0.0.1 KYON UseSsl変数をプロパティに変更
//  2016/01/25 Rev.1.0.0.0 MOTO 作成
//
///////////////////////////////////////////////////////////////////////////////////////////////////

using Act.Dcws;

namespace ACTSOAPCSCalcOneWay
{
    /// <summary>
    /// 距離計算サービスに使用する設定を指定します。
    /// </summary>
    internal static class CalcSettings
    {
        //=========================================================================================
        //  Public Constants
        //=========================================================================================
        #region Public Constants

        /// <summary>
        /// 管理サービスURLの既定値です。
        /// </summary>
        public static readonly string DefaultAdminUrl = 
            @"https://distcalc.act-inc.co.jp/dcadmin/admin.asmx";

        /// <summary>
        /// 使用する計算用道路データ（000で始まる）のNWIDの正規表現です。
        /// </summary>
        public static readonly string NWIDPattern = "^(000)";

        /// <summary>
        /// 経緯度の測地系を指定します。日本測地系。
        /// </summary>
        public static readonly Datum Datum = Datum.Tokyo;

        /// <summary>
        /// 経緯度の座標フォーマット識別子を指定します。現在は常に0を指定します。
        /// </summary>
        public static readonly int CoordinateFormat = 0;

        /// <summary>
        /// 計算方法を指定します。時間最短。
        /// </summary>
        public static readonly CalcKind CalcKind = CalcKind.Time;

        /// <summary>
        /// 使用交通機関を指定します。
        /// 使用する交通機関が複数ある場合はその論理和を指定します。
        /// </summary>
        public static readonly Transport Transport = Transport.Highway;

        /// <summary>
        /// ジオロケーション構造体の高速道路区間の出力を指定します。出力しない。
        /// </summary>
        public static readonly HighwayOutput HighwayOutput = HighwayOutput.NotOutput;

        /// <summary>
        /// ジオロケーション構造体の通行料金の出力を指定します。出力しない。
        /// </summary>
        public static readonly TollOutput TollOutput = TollOutput.NotOutput;

        #endregion

        //=========================================================================================
        //  Public Property
        //=========================================================================================
        #region Public Property

        /// <summary>
        /// 通信プロトコルにSSLを使用するかどうかを指定します。
        /// true：SSLを使用する、false：SSLを使用しない
        /// </summary>
        public static bool UseSsl { get; set; } = false;

        #endregion
    }
}
