﻿///////////////////////////////////////////////////////////////////////////////////////////////////
// 
//  ACT距離計算サービス サンプルプログラム
//  ProgressDialogクラス
//
//  Copyrights (c) 2016 Advanced Core Technologies, Inc. All rights reserved.
//
//  2016/01/26 Rev.1.0.0.0 MOTO 作成
//
///////////////////////////////////////////////////////////////////////////////////////////////////

using System;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace ACTSOAPCSCalcOneWay
{
    /// <summary>
    /// 非同期で処理を実行し、マーキースタイルのプログレスバーを表示します。
    /// </summary>
    public partial class ProgressDialog : Form
    {
        //=========================================================================================
        //  Constructors
        //=========================================================================================
        #region Constructors

        /// <summary>
        /// 表示するメッセージを指定して初期化します。
        /// </summary>
        /// <param name="message">表示するメッセージ</param>>
        public ProgressDialog(string message)
        {
            InitializeComponent();
            labelMessage.Text = message;
        }

        #endregion

        //=========================================================================================
        //  Private Fields
        //=========================================================================================
        #region Private Fields

        /// <summary>
        /// 実行中フラグです。
        /// </summary>
        private bool isRunning_;

        #endregion

        //=========================================================================================
        //  Public Methods
        //=========================================================================================
        #region Public Methods

        /// <summary>
        /// ダイアログをモーダルで表示し、指定した処理を非同期で実行します。
        /// </summary>
        /// <param name="action">実行する処理</param>
        /// <param name="message">表示するメッセージ</param>
        public static void Run(Action action, string message)
        {
            using (ProgressDialog dialog = new ProgressDialog(message))
            {
                var uiContext = TaskScheduler.FromCurrentSynchronizationContext();
                Task.Factory.StartNew(() =>
                {
                    dialog.isRunning_ = true;
                    action();
                })
                .ContinueWith(notUse =>
                {
                    dialog.isRunning_ = false;
                    dialog.Close();
                }, uiContext);

                dialog.ShowDialog();
            }
        }

        #endregion

        //=========================================================================================
        //  Event Handlers
        //=========================================================================================
        #region Event Handlers

        /// <summary>
        /// フォームのクローズ中イベントです。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ProgressDialog_FormClosing(object sender, FormClosingEventArgs e)
        {
            e.Cancel = isRunning_;
        }

        #endregion
    }
}
