﻿///////////////////////////////////////////////////////////////////////////////////////////////////
// 
//  ACT距離計算サービス サンプルプログラム
//  ユーザクラス
//
//  Copyrights (c) 2011 Advanced Core Technologies, Inc. All rights reserved.
//
//  2011/08/25 Rev.2.2.0.0 ISHI 作成
//
///////////////////////////////////////////////////////////////////////////////////////////////////

using System;

namespace ACTSOAPCSCalcOneWay
{
    /// <summary>
    /// ユーザクラス
    /// </summary>
    public class User
    {
        //=========================================================================================
        //  Public Methods
        //=========================================================================================
        #region Public Methods

        /// <summary>
        /// コンストラクタ
        /// </summary>
        /// <param name="userID">ユーザID</param>
        /// <param name="password">パスワード</param>
        /// <param name="adminUrl">管理サービスURL</param>
        /// <param name="sslMode">SSLモード</param>
        public User(string userID, string password, string adminUrl, bool sslMode)
        {
            this.userID_ = userID;
            this.password_ = password;
            this.adminUrl_ = adminUrl;
            this.sslMode_ = sslMode;
        }

        /// <summary>
        /// 管理サービス用環境設定オブジェクトを取得する
        /// </summary>
        /// <returns>管理サービス用環境設定オブジェクト</returns>
        public DCAdmin.Environ GetAdminEnviron()
        {
            DCAdmin.Environ adminEnviron = new DCAdmin.Environ();
            adminEnviron.UserID = this.userID_;
            adminEnviron.UUID = this.password_;
            return adminEnviron;
        }

        /// <summary>
        /// 最終距離計算日時を更新する
        /// </summary>
        public void UpdateLastDCTime()
        {
            this.lastDCTime_ = DateTime.Now;
        }

        /// <summary>
        /// 最終住所検索日時を更新する
        /// </summary>
        public void UpdateLastGCTime()
        {
            this.lastGCTime_ = DateTime.Now;
        }

        #endregion

        //=========================================================================================
        //  Public Properties
        //=========================================================================================
        #region Public Properties

        /// <summary>
        /// ユーザIDを取得する
        /// </summary>
        public string UserID
        {
            get { return this.userID_; }
        }

        /// <summary>
        /// パスワードを取得する
        /// </summary>
        public string Password
        {
            get { return this.password_; }
        }

        /// <summary>
        /// 管理サービスURLを取得する
        /// </summary>
        public string AdminUrl
        {
            get { return Utilities.ChangeProtocol(this.adminUrl_, this.sslMode_); }
        }

        /// <summary>
        /// SSLモードを取得する
        /// </summary>   
        public bool SslMode
        {
            get { return this.sslMode_; }
        }

        /// <summary>
        /// 最終距離計算時刻を取得する
        /// </summary>   
        public DateTime LastDCTime
        {
            get { return this.lastDCTime_; }
        }

        /// <summary>
        /// 最終住所検索時刻を取得する
        /// </summary>   
        public DateTime LastGCTime
        {
            get { return this.lastGCTime_; }
        }

        /// <summary>
        /// 利用する計算用道路データ情報を取得・設定する
        /// </summary>
        public DCAdmin.NWInfo NWInfo
        {
            get { return this.nwInfo_; }
            set { this.nwInfo_ = value; }
        }

        /// <summary>
        /// サービスユーザ情報を取得・設定する
        /// </summary>
        public DCAdmin.UserInformation2 UserInfo
        {
            get { return this.userInfo_; }
            set { this.userInfo_ = value; }
        }

        #endregion

        //=========================================================================================
        //  Private Fields
        //=========================================================================================
        #region Private Fields

        /// <summary>
        /// ユーザID
        /// </summary>
        private string userID_;

        /// <summary>
        /// パスワード
        /// </summary>
        private string password_;

        /// <summary>
        /// 管理サービスURL
        /// </summary>
        /// <remarks></remarks>
        private string adminUrl_;

        /// <summary>
        /// SSLモード
        /// </summary>
        /// <remarks></remarks>
        private bool sslMode_;

        /// <summary>
        /// 最終距離計算時刻
        /// </summary>
        private DateTime lastDCTime_;

        /// <summary>
        /// 最終住所検索時刻
        /// </summary>
        private DateTime lastGCTime_;

        /// <summary>
        /// 利用する計算用道路データ情報
        /// </summary>
        private DCAdmin.NWInfo nwInfo_;

        /// <summary>
        /// サービスユーザ情報
        /// </summary>
        private DCAdmin.UserInformation2 userInfo_;

        #endregion
    }
}
